@@ -6,6 +6,17 @@ import unittest
 
 #SKIP_FILES = ['common', 'runtests']
 
+if len(sys.argv) > 1:
+    builddir = sys.argv[1]
+    no_import_hooks = True
+else:
+    builddir = '..'
+    no_import_hooks = False
+
+import common
+common.run_import_tests(builddir, no_import_hooks)
+
+
 dir = os.path.split(os.path.abspath(__file__))[0]
 os.chdir(dir)
 
